@@ -14,24 +14,39 @@ use POSIX qw( :fcntl_h ) ;
 use vars qw( @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION ) ;
 @ISA = qw( Exporter ) ;
 
-$VERSION = '9999.17';
+$VERSION = '9999.18';
 
-@EXPORT_OK = qw(
-	slurp
-	prepend_file
-	edit_file
-	edit_file_lines
-) ;
-
-%EXPORT_TAGS = ( 'all' => [ qw(
+my @std_export = qw(
 	read_file
 	write_file
 	overwrite_file
 	append_file
-	read_dir ),
-	@EXPORT_OK	
-] ) ;
-@EXPORT = ( @{ $EXPORT_TAGS{'all'} } );
+	read_dir
+) ;
+
+my @edit_export = qw( 
+	edit_file
+	edit_file_lines
+) ;
+
+my @ok_export = qw( 
+) ;
+
+@EXPORT_OK = (
+	@edit_export,
+	qw(
+		slurp
+		prepend_file
+	),
+) ;
+
+%EXPORT_TAGS = (
+	'all'	=> [ @std_export, @edit_export, @EXPORT_OK ],
+	'edit'	=> [ @edit_export ],
+	'std'	=> [ @std_export ],
+) ;
+
+@EXPORT = @std_export ;
 
 my $max_fast_slurp_size = 1024 * 100 ;
 
@@ -1125,8 +1140,12 @@ them is that C<edit_file> reads the whole file into $_ and calls the
 code block one time. With C<edit_file_lines> each line is read into $_
 and the code is called for each line. In both cases the code should
 modify $_ if desired and it will be written back out. These subs are
-the equivilent of the -pi command line options of Perl but you can
-call them from inside your program and not fork out a process.
+the equivalent of the -pi command line options of Perl but you can
+call them from inside your program and not fork out a process. They
+are in @EXPORT_OK so you need to request them to be imported on the
+use line or you can import both of them with:
+
+	use File::Slurp qw( :edit ) ;
 
 The first argument to C<edit_file> and C<edit_file_lines> is a code
 block or a code reference. The code block is not followed by a comma
@@ -1141,16 +1160,17 @@ C<write_file> call has the C<atomic> option set so you will always
 have a consistant file. See above for more about those options.
 
 Each group of calls below show a Perl command line instance and the
-equivilent calls to C<edit_file> and C<edit_file_lines>.
+equivalent calls to C<edit_file> and C<edit_file_lines>.
 
 	perl -0777 -pi -e 's/foo/bar/g' filename
-	use File::Slurp ;
+	use File::Slurp qw( edit_file ) ;
 	edit_file { s/foo/bar/g } 'filename' ;
 	edit_file sub { s/foo/bar/g }, 'filename' ;
 	edit_file \&replace_foo, 'filename' ;
 	sub replace_foo { s/foo/bar/g }
 
 	perl -pi -e '$_ = '' if /foo/' filename
+	use File::Slurp qw( edit_file_lines ) ;
 	use File::Slurp ;
 	edit_file_lines { $_ = '' if /foo/ } 'filename' ;
 	edit_file_lines sub { $_ = '' if /foo/ }, 'filename' ;
@@ -1196,8 +1216,19 @@ of entries when opening themn.
 
 =head2 EXPORT
 
+  These are exported by default or with
+	use File::Slurp qw( :std ) ;
+
   read_file write_file overwrite_file append_file read_dir
 
+  These are exported with
+	use File::Slurp qw( :edit ) ;
+
+  edit_file edit_file_lines
+
+  You can get all subs in the module exported with 
+	use File::Slurp qw( :all ) ;
+
 =head2 LICENSE
 
   Same as Perl.
